@@ -1,6 +1,5 @@
 """Colliders used for collision detection with GJK algorithm."""
 import abc
-import re
 import warnings
 import numpy as np
 from pytransform3d import urdf
@@ -11,6 +10,7 @@ from .geometry import (
 from .containment import (
     axis_aligned_bounding_box, sphere_aabb, box_aabb, cylinder_aabb,
     capsule_aabb)
+from .urdf_utils import self_collision_whitelists
 from aabbtree import AABB, AABBTree
 
 
@@ -38,7 +38,7 @@ class BoundingVolumeHierarchy:
         Maps frames of collision objects to colliders.
 
     self_collision_whitelists_ : dict
-        Whitelists for self collision detection in case this BVH represents
+        Whitelists for self-collision detection in case this BVH represents
         a robot.
     """
     def __init__(self, tm, base_frame):
@@ -75,7 +75,7 @@ class BoundingVolumeHierarchy:
                 warnings.warn(str(e))
 
         if fill_self_collision_whitelists:
-            self._fill_self_collision_whitelists(tm)
+            self.self_collision_whitelists_ = self_collision_whitelists(tm)
 
     def _make_collider(self, tm, obj, make_artists):
         A2B = tm.get_transform(obj.frame, self.base_frame)
@@ -94,19 +94,6 @@ class BoundingVolumeHierarchy:
             collider.make_artist()
         return collider
 
-    def _fill_self_collision_whitelists(self, tm):
-        link_info = LinkInfo(tm)
-        for obj in tm.collision_objects:
-            link_frame = link_info.link(obj.frame)
-            parent_frame = link_info.parent_link(link_frame)
-            child_frame = link_info.child_link(link_frame)
-            collision_objects_link = link_info.collision_frames_attached_to_link(link_frame)
-            collision_objects_parent = link_info.collision_frames_attached_to_link(parent_frame)
-            collision_objects_child = link_info.collision_frames_attached_to_link(child_frame)
-            self.self_collision_whitelists_[obj.frame] = (
-                collision_objects_link + collision_objects_parent
-                + collision_objects_child)
-
     def add_collider(self, frame, collider):
         """Add collider.
 
@@ -189,56 +176,6 @@ class BoundingVolumeHierarchy:
         return self.collider_frames
 
 
-class LinkInfo:  # TODO move to another module?
-    """Collect information about links from a UrdfTransformManager.
-
-    Parameters
-    ----------
-    tm : pytransform3d.urdf.UrdfTransformManager
-        Transform manager.
-    """
-    def __init__(self, tm):
-        self.tm = tm
-        self.parent_links = {}
-        self.child_links = {}
-        for child, parent in tm.transforms:
-            self.parent_links[child] = parent
-            self.child_links[parent] = child
-        # HACK uses naming convention from URDF parser to extract link
-        #      of a collision object
-        self.prog_match_link = re.compile(r"collision:(.*)\/.*")
-
-    def link(self, frame):
-        result = self.prog_match_link.match(frame)
-        if result is None:
-            warnings.warn(
-                f"Couldn't extract link of collision object at frame '{frame}'")
-            return None
-        else:
-            link_frame = result.group(1)
-            return link_frame
-
-    def child_link(self, link_frame):
-        return self._connected_link(self.child_links, link_frame)
-
-    def parent_link(self, link_frame):
-        return self._connected_link(self.parent_links, link_frame)
-
-    @staticmethod
-    def _connected_link(relation_info, link_frame):
-        return relation_info.get(link_frame, None)
-
-    def collision_frames_attached_to_link(self, link_frame):
-        collision_frames = []
-        # HACK uses naming convention from URDF parser to extract link
-        #      of a collision object
-        prog = re.compile(f"collision:{link_frame}" + r"\/.*")
-        for node in self.tm.nodes:
-            if prog.match(node):
-                collision_frames.append(node)
-        return collision_frames
-
-
 # for backwards compatibility:
 ColliderTree = BoundingVolumeHierarchy
 
@@ -443,10 +380,6 @@ class Mesh(Convex):
         self.artist_.set_data(pose)
         self.vertices_ = np.asarray(self.artist_.mesh.vertices)
 
-    def aabb(self):
-        mins, maxs = axis_aligned_bounding_box(self.vertices_)
-        return AABB(np.array([mins, maxs]).T)
-
 
 class Cylinder(ConvexCollider):
     """Wraps cylinder for GJK algorithm.
