@@ -1,7 +1,8 @@
 import math
 import numpy as np
-from ..geometry import hesse_normal_form
+from ..geometry import line_from_pluecker
 from ._line import point_to_line
+from ._plane import plane_intersects_plane
 
 
 def point_to_disk(point, center, radius, normal):
@@ -98,7 +99,7 @@ def disk_to_disk(center1, radius1, normal1, center2, radius2, normal2, epsilon=1
     # (1) test intersection first (source: https://stackoverflow.com/a/67116330/915743)
     # Plücker coordinates of intersection line
     line_direction, line_moment = plane_intersects_plane(center1, normal1, center2, normal2)
-    line_point = np.cross(line_direction, line_moment) / np.dot(line_direction, line_direction)
+    line_point, line_direction = line_from_pluecker(line_direction, line_moment)
     h1, p1 = point_to_line(center1, line_point, line_direction)
     h2, p2 = point_to_line(center2, line_point, line_direction)
     ell = np.linalg.norm(p2 - p1)
@@ -126,13 +127,3 @@ def disk_to_disk(center1, radius1, normal1, center2, radius2, normal2, epsilon=1
             break
         prev_dist = dist
     return np.linalg.norm(contact_point_disk2 - contact_point_disk1), contact_point_disk1, contact_point_disk2
-
-
-# TODO find a better place
-def plane_intersects_plane(
-        plane_point1, plane_normal1, plane_point2, plane_normal2):
-    _, d1 = hesse_normal_form(plane_point1, plane_normal1)
-    _, d2 = hesse_normal_form(plane_point2, plane_normal2)
-    line_direction = np.cross(plane_normal1, plane_normal2)
-    line_moment = plane_normal1 * d2 - plane_normal2 * d1
-    return line_direction, line_moment
