@@ -3,7 +3,8 @@ import pytransform3d.transformations as pt
 
 
 def point_to_ellipsoid(
-        point, ellipsoid2origin, radii, epsilon=1e-16, max_iter=64):
+        point, ellipsoid2origin, radii, distance_to_surface=False,
+        epsilon=1e-16, max_iter=64, check=False):
     """Compute the shortest distance between point and ellipsoid.
 
     Implementation adapted from 3D Game Engine Design by David H. Eberly.
@@ -29,12 +30,18 @@ def point_to_ellipsoid(
     radii : array, shape (3,)
         Radii of the ellipsoid.
 
+    distance_to_surface : bool, optional (default: False)
+        Compute distance to surface or volume otherwise.
+
     epsilon : float, optional (default: 1e-16)
         Values smaller than epsilon are considered to be 0.
 
     max_iter : int, optional (default: 64)
         Maximum number of iterations of the optimization.
 
+    check : bool, optional (default: True)
+        Check if transformation matrix is valid before inversion.
+
     Returns
     -------
     dist : float
@@ -44,18 +51,28 @@ def point_to_ellipsoid(
         Closest point on ellipsoid.
     """
     # compute coordinates of point in ellipsoid coordinate system
-    point_in_ellipsoid = pt.transform(pt.invert_transform(ellipsoid2origin),
-                                      pt.vector_to_point(point))[:3]
+    origin2ellipsoid = pt.invert_transform(ellipsoid2origin, check=check)
+    point_in_ellipsoid = origin2ellipsoid[:3, 3] + origin2ellipsoid[:3, :3].dot(point)
 
     radii2 = radii ** 2
     point2 = point_in_ellipsoid ** 2
     radii2point2 = radii2 * point2
 
     # initial guess
-    if np.linalg.norm(point_in_ellipsoid / radii) < 1.0:
-        # TODO in case we want to compute the distance to the surface:
-        #t = 0.0  # and don't return here:
-        return 0.0, point
+    normalized_point_norm = np.linalg.norm(point_in_ellipsoid / radii)
+    if normalized_point_norm < 1.0:
+        if distance_to_surface:
+            if normalized_point_norm < 100.0 * epsilon:
+                # Point is the center of the ellipsoid, we have two possible
+                # solutions on opposite sides and must select one.
+                min_radius_idx = np.argmin(radii)
+                closest_point = (
+                    ellipsoid2origin[:3, 3]
+                    + radii[min_radius_idx] * ellipsoid2origin[:3, min_radius_idx])
+                return radii[min_radius_idx], closest_point
+            t = 0.0
+        else:
+            return 0.0, point
     else:
         t = max(radii) * np.linalg.norm(point_in_ellipsoid)
 
@@ -80,10 +97,11 @@ def point_to_ellipsoid(
                     - radii2point2[2] * pq * (pqr[0] + pqr[1]))
         t -= s / ds
 
-    contact_point_in_ellipsoid = radii2 * point_in_ellipsoid / pqr
-    diff = contact_point_in_ellipsoid - point_in_ellipsoid
+    closest_point_in_ellipsoid = radii2 * point_in_ellipsoid / pqr
+    diff = closest_point_in_ellipsoid - point_in_ellipsoid
 
-    closest_point_ellipsoid = pt.transform(
-        ellipsoid2origin, pt.vector_to_point(contact_point_in_ellipsoid))[:3]
+    closest_point_ellipsoid = (
+        ellipsoid2origin[:3, 3]
+        + ellipsoid2origin[:3, :3].dot(closest_point_in_ellipsoid))
 
     return np.linalg.norm(diff), closest_point_ellipsoid
