@@ -1,5 +1,6 @@
 """Tools for geometric computations."""
 import math
+from itertools import product
 import numpy as np
 
 
@@ -35,6 +36,10 @@ def convert_rectangle_to_segment(rectangle_center, rectangle_extents, i0, i1):
     return segment_end, segment_start
 
 
+RECTANGLE_COORDS = np.array([
+    [-0.5, -0.5], [-0.5, 0.5], [0.5, -0.5], [0.5, 0.5]])
+
+
 def convert_rectangle_to_vertices(
         rectangle_center, rectangle_axes, rectangle_lengths):
     """Convert rectangle to vertices.
@@ -56,12 +61,7 @@ def convert_rectangle_to_vertices(
     rectangle_points : array, shape (4, 3)
         Vertices of the rectangle.
     """
-    return np.array([
-        rectangle_center
-        + 0.5 * a * rectangle_axes[0] * rectangle_lengths[0]
-        + 0.5 * b * rectangle_axes[1] * rectangle_lengths[1]
-        for a in [-1, 1] for b in [-1, 1]
-    ])
+    return rectangle_center + (RECTANGLE_COORDS * rectangle_lengths).dot(rectangle_axes)
 
 
 def convert_box_to_face(box2origin, size, i, sign):
@@ -127,6 +127,9 @@ def convert_segment_to_line(segment_start, segment_end):
     return segment_direction, segment_length
 
 
+BOX_COORDS = np.array(list(product([-0.5, 0.5], repeat=3)))
+
+
 def convert_box_to_vertices(box2origin, size):
     """Convert box to vertices.
 
@@ -143,13 +146,7 @@ def convert_box_to_vertices(box2origin, size):
     box_points : array, shape (8, 3)
         Vertices of the box.
     """
-    box_points = np.array([
-        box2origin[:3, 3]
-        + 0.5 * sign0 * box2origin[:3, 0] * size[0]
-        + 0.5 * sign1 * box2origin[:3, 1] * size[1]
-        + 0.5 * sign2 * box2origin[:3, 2] * size[2]
-        for sign0 in [-1, 1] for sign1 in [-1, 1] for sign2 in [-1, 1]])
-    return box_points
+    return box2origin[:3, 3] + (BOX_COORDS * size).dot(box2origin[:3, :3].T)
 
 
 def cylinder_extreme_along_direction(
@@ -184,7 +181,7 @@ def cylinder_extreme_along_direction(
     """
     local_dir = np.dot(cylinder2origin[:3, :3].T, search_direction)
 
-    s = math.sqrt(local_dir[0] ** 2 + local_dir[1] ** 2)
+    s = math.sqrt(local_dir[0] * local_dir[0] + local_dir[1] * local_dir[1])
     if local_dir[2] < 0.0:
         z = -0.5 * length
     else:
@@ -194,7 +191,7 @@ def cylinder_extreme_along_direction(
         local_vertex = np.array([local_dir[0] * d, local_dir[1] * d, z])
     else:
         local_vertex = np.array([radius, 0.0, z])
-    return np.dot(cylinder2origin[:3, :3], local_vertex) + cylinder2origin[:3, 3]
+    return cylinder2origin[:3, 3] + np.dot(cylinder2origin[:3, :3], local_vertex)
 
 
 def capsule_extreme_along_direction(
@@ -227,20 +224,21 @@ def capsule_extreme_along_direction(
     extreme_point : array, shape (3,)
         Extreme point along search direction.
     """
-    # TODO error with axis-aligned capsules
     local_dir = np.dot(capsule2origin[:3, :3].T, search_direction)
 
-    s = np.linalg.norm(local_dir)
+    s = math.sqrt(local_dir[0] * local_dir[0] + local_dir[1] * local_dir[1]
+                  + local_dir[2] * local_dir[2])
+    # TODO error with axis-aligned capsules?
     if s == 0.0:
         local_vertex = np.zeros(3)
     else:
-        local_vertex = local_dir / s * radius
+        local_vertex = local_dir * (radius / s)
     if local_dir[2] > 0.0:
         local_vertex[2] += 0.5 * height
     else:
         local_vertex[2] -= 0.5 * height
 
-    return np.dot(capsule2origin[:3, :3], local_vertex) + capsule2origin[:3, 3]
+    return capsule2origin[:3, 3] + np.dot(capsule2origin[:3, :3], local_vertex)
 
 
 def hesse_normal_form(plane_point, plane_normal):
@@ -267,3 +265,28 @@ def hesse_normal_form(plane_point, plane_normal):
         Distance of the plane to origin in Hesse normal form.
     """
     return plane_normal, np.dot(plane_point, plane_normal)
+
+
+def line_from_pluecker(line_direction, line_moment):
+    """Computes line from Plücker coordinates.
+
+    Parameters
+    ----------
+    line_direction : array, shape (3,)
+        Direction of the line. Not necessarily of unit length.
+
+    line_moment : array, shape (3,)
+        Moment of the line.
+
+    Returns
+    -------
+    line_point : array, shape (3,)
+        Point on line.
+
+    line_direction : array, shape (3,)
+        Direction of the line. This is assumed to be of unit length.
+    """
+    line_dir_norm_squared = np.dot(line_direction, line_direction)
+    line_point = np.cross(line_direction, line_moment) / line_dir_norm_squared
+    line_direction = line_direction / math.sqrt(line_dir_norm_squared)
+    return line_point, line_direction
