@@ -260,6 +260,30 @@ def rand_capsule(random_state, center_scale=1.0, radius_scale=1.0,
     return capsule2origin, radius, height
 
 
+def rand_ellipsoid(random_state, min_radius=0.0):
+    """Sample ellipsoid.
+
+    Parameters
+    ----------
+    random_state : np.random.RandomState
+        Random number generator.
+
+    min_radius : float, optional (default: 0)
+        Minimum radius of ellipsoid.
+
+    Returns
+    -------
+    ellipsoid2origin : array, shape (4, 4)
+        Pose of the ellipsoid.
+
+    radii : array, shape (3,)
+        Radii of the ellipsoid within (min_radius, min_radius + 1].
+    """
+    ellipsoid2origin = pt.random_transform(random_state)
+    radii = min_radius + 1.0 - random_state.rand(3)
+    return ellipsoid2origin, radii
+
+
 def rand_cylinder(random_state, center_scale=1.0, min_radius=0.0,
                   min_length=0.0):
     """Sample cylinder.
@@ -341,7 +365,7 @@ def randn_convex(random_state, n_points=10, center_scale=1.0, std=1.0, return_in
         Standard deviation of normal distribution.
 
     return_indices : bool, optional (default: False)
-        Return indices of vertices in faces.
+        Return indices of vertices in faces and all points.
 
     Returns
     -------
@@ -351,15 +375,31 @@ def randn_convex(random_state, n_points=10, center_scale=1.0, std=1.0, return_in
     faces : array, shape (n_triangles, 3, 3)
         Vertices organized as triangles.
 
-    indices : array, shape (n_triangles, 3)
+    points : array, shape (n_points,), optional
+        All points that have been sampled from normal distribution.
+
+    indices : array, shape (n_triangles, 3), optional
         Indices of points forming the simplical facets of the convex hull.
     """
     points = random_state.randn(n_points, 3) * std
-    points += random_state.randn(1, 3) * center_scale
-    ch = ConvexHull(points)
+    ch = ConvexHull(points, qhull_options="Qf")
+    simplices = ch.simplices
+    faces = np.array([points[[i, j, k]] for i, j, k in simplices])
+
+    reordered_indices = np.array([2, 1, 0], dtype=int)
+    for face_idx in range(len(faces)):
+        if pr.angle_between_vectors(
+                np.cross(faces[face_idx, 2] - faces[face_idx, 0],
+                         faces[face_idx, 1] - faces[face_idx, 0]),
+                np.mean(faces[face_idx], axis=0)) < 0.5 * np.pi:
+            faces[face_idx] = faces[face_idx, reordered_indices]
+            simplices[face_idx] = simplices[face_idx, reordered_indices]
+
+    center = random_state.randn(1, 3) * center_scale
+    points += center
+    faces += center
     vertices = points[ch.vertices]
-    faces = np.array([points[[i, j, k]] for i, j, k in ch.simplices])
     ret = [vertices, faces]
     if return_indices:
-        ret.extend([ch.points, ch.simplices])
+        ret.extend([ch.points, simplices])
     return ret
